@@ -22,8 +22,7 @@ Usage::
 from datetime import datetime
 from typing import Generic, Iterator, TypeVar, Union
 
-from botocore.paginate import PageIterator
-from botocore.paginate import Paginator as Boto3Paginator
+from botocore.paginate import PageIterator, Paginator
 
 from .literals import SortOrderType
 from .type_defs import ListHumanLoopsResponseTypeDef, PaginatorConfigTypeDef
@@ -41,7 +40,7 @@ class _PageIterator(Generic[_ItemTypeDef], PageIterator):
         """
 
 
-class ListHumanLoopsPaginator(Boto3Paginator):
+class ListHumanLoopsPaginator(Paginator):
     """
     [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/sagemaker-a2i-runtime.html#AugmentedAIRuntime.Paginator.ListHumanLoops)
     [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_sagemaker_a2i_runtime/paginators/#listhumanloopspaginator)
