@@ -26,19 +26,19 @@ else:
 __all__ = (
     "DeleteHumanLoopRequestRequestTypeDef",
     "DescribeHumanLoopRequestRequestTypeDef",
-    "DescribeHumanLoopResponseTypeDef",
+    "HumanLoopOutputTypeDef",
+    "ResponseMetadataTypeDef",
     "HumanLoopDataAttributesTypeDef",
     "HumanLoopInputTypeDef",
-    "HumanLoopOutputTypeDef",
     "HumanLoopSummaryTypeDef",
-    "ListHumanLoopsRequestListHumanLoopsPaginateTypeDef",
-    "ListHumanLoopsRequestRequestTypeDef",
-    "ListHumanLoopsResponseTypeDef",
     "PaginatorConfigTypeDef",
-    "ResponseMetadataTypeDef",
-    "StartHumanLoopRequestRequestTypeDef",
-    "StartHumanLoopResponseTypeDef",
+    "ListHumanLoopsRequestRequestTypeDef",
     "StopHumanLoopRequestRequestTypeDef",
+    "DescribeHumanLoopResponseTypeDef",
+    "StartHumanLoopResponseTypeDef",
+    "StartHumanLoopRequestRequestTypeDef",
+    "ListHumanLoopsResponseTypeDef",
+    "ListHumanLoopsRequestListHumanLoopsPaginateTypeDef",
 )
 
 DeleteHumanLoopRequestRequestTypeDef = TypedDict(
@@ -55,18 +55,21 @@ DescribeHumanLoopRequestRequestTypeDef = TypedDict(
     },
 )
 
-DescribeHumanLoopResponseTypeDef = TypedDict(
-    "DescribeHumanLoopResponseTypeDef",
+HumanLoopOutputTypeDef = TypedDict(
+    "HumanLoopOutputTypeDef",
     {
-        "CreationTime": datetime,
-        "FailureReason": str,
-        "FailureCode": str,
-        "HumanLoopStatus": HumanLoopStatusType,
-        "HumanLoopName": str,
-        "HumanLoopArn": str,
-        "FlowDefinitionArn": str,
-        "HumanLoopOutput": "HumanLoopOutputTypeDef",
-        "ResponseMetadata": "ResponseMetadataTypeDef",
+        "OutputS3Uri": str,
+    },
+)
+
+ResponseMetadataTypeDef = TypedDict(
+    "ResponseMetadataTypeDef",
+    {
+        "RequestId": str,
+        "HostId": str,
+        "HTTPStatusCode": int,
+        "HTTPHeaders": Dict[str, str],
+        "RetryAttempts": int,
     },
 )
 
@@ -84,13 +87,6 @@ HumanLoopInputTypeDef = TypedDict(
     },
 )
 
-HumanLoopOutputTypeDef = TypedDict(
-    "HumanLoopOutputTypeDef",
-    {
-        "OutputS3Uri": str,
-    },
-)
-
 HumanLoopSummaryTypeDef = TypedDict(
     "HumanLoopSummaryTypeDef",
     {
@@ -103,31 +99,16 @@ HumanLoopSummaryTypeDef = TypedDict(
     total=False,
 )
 
-_RequiredListHumanLoopsRequestListHumanLoopsPaginateTypeDef = TypedDict(
-    "_RequiredListHumanLoopsRequestListHumanLoopsPaginateTypeDef",
+PaginatorConfigTypeDef = TypedDict(
+    "PaginatorConfigTypeDef",
     {
-        "FlowDefinitionArn": str,
-    },
-)
-_OptionalListHumanLoopsRequestListHumanLoopsPaginateTypeDef = TypedDict(
-    "_OptionalListHumanLoopsRequestListHumanLoopsPaginateTypeDef",
-    {
-        "CreationTimeAfter": Union[datetime, str],
-        "CreationTimeBefore": Union[datetime, str],
-        "SortOrder": SortOrderType,
-        "PaginationConfig": "PaginatorConfigTypeDef",
+        "MaxItems": int,
+        "PageSize": int,
+        "StartingToken": str,
     },
     total=False,
 )
 
-
-class ListHumanLoopsRequestListHumanLoopsPaginateTypeDef(
-    _RequiredListHumanLoopsRequestListHumanLoopsPaginateTypeDef,
-    _OptionalListHumanLoopsRequestListHumanLoopsPaginateTypeDef,
-):
-    pass
-
-
 _RequiredListHumanLoopsRequestRequestTypeDef = TypedDict(
     "_RequiredListHumanLoopsRequestRequestTypeDef",
     {
@@ -153,33 +134,33 @@ class ListHumanLoopsRequestRequestTypeDef(
     pass
 
 
-ListHumanLoopsResponseTypeDef = TypedDict(
-    "ListHumanLoopsResponseTypeDef",
+StopHumanLoopRequestRequestTypeDef = TypedDict(
+    "StopHumanLoopRequestRequestTypeDef",
     {
-        "HumanLoopSummaries": List["HumanLoopSummaryTypeDef"],
-        "NextToken": str,
-        "ResponseMetadata": "ResponseMetadataTypeDef",
+        "HumanLoopName": str,
     },
 )
 
-PaginatorConfigTypeDef = TypedDict(
-    "PaginatorConfigTypeDef",
+DescribeHumanLoopResponseTypeDef = TypedDict(
+    "DescribeHumanLoopResponseTypeDef",
     {
-        "MaxItems": int,
-        "PageSize": int,
-        "StartingToken": str,
+        "CreationTime": datetime,
+        "FailureReason": str,
+        "FailureCode": str,
+        "HumanLoopStatus": HumanLoopStatusType,
+        "HumanLoopName": str,
+        "HumanLoopArn": str,
+        "FlowDefinitionArn": str,
+        "HumanLoopOutput": HumanLoopOutputTypeDef,
+        "ResponseMetadata": ResponseMetadataTypeDef,
     },
-    total=False,
 )
 
-ResponseMetadataTypeDef = TypedDict(
-    "ResponseMetadataTypeDef",
+StartHumanLoopResponseTypeDef = TypedDict(
+    "StartHumanLoopResponseTypeDef",
     {
-        "RequestId": str,
-        "HostId": str,
-        "HTTPStatusCode": int,
-        "HTTPHeaders": Dict[str, str],
-        "RetryAttempts": int,
+        "HumanLoopArn": str,
+        "ResponseMetadata": ResponseMetadataTypeDef,
     },
 )
 
@@ -188,13 +169,13 @@ _RequiredStartHumanLoopRequestRequestTypeDef = TypedDict(
     {
         "HumanLoopName": str,
         "FlowDefinitionArn": str,
-        "HumanLoopInput": "HumanLoopInputTypeDef",
+        "HumanLoopInput": HumanLoopInputTypeDef,
     },
 )
 _OptionalStartHumanLoopRequestRequestTypeDef = TypedDict(
     "_OptionalStartHumanLoopRequestRequestTypeDef",
     {
-        "DataAttributes": "HumanLoopDataAttributesTypeDef",
+        "DataAttributes": HumanLoopDataAttributesTypeDef,
     },
     total=False,
 )
@@ -206,17 +187,35 @@ class StartHumanLoopRequestRequestTypeDef(
     pass
 
 
-StartHumanLoopResponseTypeDef = TypedDict(
-    "StartHumanLoopResponseTypeDef",
+ListHumanLoopsResponseTypeDef = TypedDict(
+    "ListHumanLoopsResponseTypeDef",
     {
-        "HumanLoopArn": str,
-        "ResponseMetadata": "ResponseMetadataTypeDef",
+        "HumanLoopSummaries": List[HumanLoopSummaryTypeDef],
+        "NextToken": str,
+        "ResponseMetadata": ResponseMetadataTypeDef,
     },
 )
 
-StopHumanLoopRequestRequestTypeDef = TypedDict(
-    "StopHumanLoopRequestRequestTypeDef",
+_RequiredListHumanLoopsRequestListHumanLoopsPaginateTypeDef = TypedDict(
+    "_RequiredListHumanLoopsRequestListHumanLoopsPaginateTypeDef",
     {
-        "HumanLoopName": str,
+        "FlowDefinitionArn": str,
     },
 )
+_OptionalListHumanLoopsRequestListHumanLoopsPaginateTypeDef = TypedDict(
+    "_OptionalListHumanLoopsRequestListHumanLoopsPaginateTypeDef",
+    {
+        "CreationTimeAfter": Union[datetime, str],
+        "CreationTimeBefore": Union[datetime, str],
+        "SortOrder": SortOrderType,
+        "PaginationConfig": PaginatorConfigTypeDef,
+    },
+    total=False,
+)
+
+
+class ListHumanLoopsRequestListHumanLoopsPaginateTypeDef(
+    _RequiredListHumanLoopsRequestListHumanLoopsPaginateTypeDef,
+    _OptionalListHumanLoopsRequestListHumanLoopsPaginateTypeDef,
+):
+    pass
